/*!
 * @eslint-sets/eslint-config-ts v3.0.0
 * Eslint config basic sets for typescript
 * (c) 2021-2022 saqqdy<https://github.com/saqqdy> 
 * Released under the MIT License.
 */
'use strict';

const basic = require("@eslint-sets/eslint-config-basic");
const config = {
  plugins: [
    "@typescript-eslint/eslint-plugin",
    "prettier"
  ],
  extends: [
    "@eslint-sets/eslint-config-basic",
    "plugin:import/typescript",
    "plugin:@typescript-eslint/recommended",
    "prettier"
  ],
  settings: {
    "import/resolver": {
      node: {
        extensions: [
          ".js",
          ".jsx",
          ".cjs",
          ".mjs",
          ".ts",
          ".tsx",
          ".d.ts"
        ]
      }
    }
  },
  rules: {
    "import/named": "off",
    "@typescript-eslint/no-var-requires": 0,
    "@typescript-eslint/no-extra-semi": 0,
    "@typescript-eslint/semi": ["error", "never"],
    "@typescript-eslint/ban-ts-comment": [
      "error",
      { "ts-ignore": "allow-with-description" }
    ],
    "@typescript-eslint/member-delimiter-style": [
      "error",
      { multiline: { delimiter: "none" } }
    ],
    "@typescript-eslint/type-annotation-spacing": ["error", {}],
    "@typescript-eslint/consistent-type-imports": [
      "error",
      { prefer: "type-imports", disallowTypeAnnotations: false }
    ],
    "@typescript-eslint/consistent-type-definitions": [
      "error",
      "interface"
    ],
    "@typescript-eslint/consistent-indexed-object-style": [
      "error",
      "record"
    ],
    "@typescript-eslint/prefer-ts-expect-error": "error",
    "no-useless-constructor": "off",
    "@typescript-eslint/indent": 0,
    "no-unused-vars": "off",
    "@typescript-eslint/no-unused-vars": [
      2,
      {
        argsIgnorePattern: "^h$",
        varsIgnorePattern: "^h$"
      }
    ],
    "no-redeclare": "off",
    "@typescript-eslint/no-redeclare": "error",
    "no-use-before-define": "off",
    "@typescript-eslint/no-use-before-define": [
      "error",
      { functions: false, classes: false, variables: true }
    ],
    "brace-style": "off",
    "@typescript-eslint/brace-style": [
      "error",
      "stroustrup",
      { allowSingleLine: true }
    ],
    "comma-dangle": "off",
    "@typescript-eslint/comma-dangle": ["error", "always-multiline"],
    "object-curly-spacing": "off",
    "@typescript-eslint/object-curly-spacing": ["error", "always"],
    "@typescript-eslint/camelcase": "off",
    "@typescript-eslint/explicit-function-return-type": "off",
    "@typescript-eslint/explicit-member-accessibility": "off",
    "@typescript-eslint/no-explicit-any": "off",
    "@typescript-eslint/no-parameter-properties": "off",
    "@typescript-eslint/no-empty-interface": "off",
    "@typescript-eslint/ban-ts-ignore": "off",
    "@typescript-eslint/no-empty-function": "off",
    "@typescript-eslint/no-non-null-assertion": "off",
    "@typescript-eslint/explicit-module-boundary-types": "off",
    "@typescript-eslint/ban-types": "off",
    "@typescript-eslint/no-namespace": "off"
  },
  overrides: [
    ...basic.overrides,
    {
      files: ["*.js"],
      rules: {
        "@typescript-eslint/no-var-requires": "off"
      }
    },
    {
      files: ["**/*.md/*.*"],
      rules: {
        "@typescript-eslint/no-redeclare": "off",
        "@typescript-eslint/no-unused-vars": "off",
        "@typescript-eslint/no-use-before-define": "off",
        "@typescript-eslint/no-var-requires": "off"
      }
    }
  ]
};

module.exports = config;
